django\_page\_hits.migrations package
=====================================

Submodules
----------

django\_page\_hits.migrations.0001\_initial module
--------------------------------------------------

.. automodule:: django_page_hits.migrations.0001_initial
    :members:
    :undoc-members:
    :show-inheritance:

django\_page\_hits.migrations.0002\_auto\_20201012\_1923 module
---------------------------------------------------------------

.. automodule:: django_page_hits.migrations.0002_auto_20201012_1923
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_page_hits.migrations
    :members:
    :undoc-members:
    :show-inheritance:
